@@ -8,7 +8,8 @@ import os
 
 from rex.utilities.loggers import init_mult
 from rex.utilities.cli_dtypes import STR, INT
-from rex.utilities.execution import SLURM, SubprocessManager
+from rex.utilities.hpc import SLURM
+from rex.utilities.utilities import get_class_properties
 
 from reVX.config.wind_dirs import WindDirsConfig
 from reVX.wind_dirs.wind_dirs import WindDirections
@@ -31,6 +32,14 @@ def main(ctx, name, verbose):
     ctx.obj['VERBOSE'] = verbose
 
 
+@main.command()
+def valid_config_keys():
+    """
+    Echo the valid Wind Dirs config keys
+    """
+    click.echo(', '.join(get_class_properties(WindDirsConfig)))
+
+
 def run_local(ctx, config):
     """
     Run WindDirections locally using config
@@ -165,28 +174,27 @@ def get_node_cmd(config):
     cmd : str
         CLI call to submit to SLURM execution.
     """
-    s = SubprocessManager.s
 
-    args = ('-n {name} local -prh5 {pr_h5} -excl {excl_h5} -o {out_dir} '
-            '-ad {agg_dset} -td {tm_dset} -res {res} -ea {excl_area} '
-            '-mw {workers} -cpl {chunks} -log {log_dir} '
-            .format(name=s(config.name),
-                    pr_h5=s(config.powerrose_h5_fpath),
-                    excl_h5=s(config.excl_fpath),
-                    out_dir=s(config.dirout),
-                    agg_dset=s(config.agg_dset),
-                    tm_dset=s(config.tm_dset),
-                    res=s(config.resolution),
-                    excl_area=s(config.excl_area),
-                    workers=s(config.max_workers),
-                    chunks=s(config.chunk_point_len),
-                    log_dir=s(config.logdir)))
+    args = ['-n {}'.format(SLURM.s(config.name)),
+            'local',
+            '-prh5 {}'.format(SLURM.s(config.powerrose_h5_fpath)),
+            '-excl {}'.format(SLURM.s(config.excl_fpath)),
+            '-o {}'.format(SLURM.s(config.dirout)),
+            '-ad {}'.format(SLURM.s(config.agg_dset)),
+            '-td {}'.format(SLURM.s(config.tm_dset)),
+            '-res {}'.format(SLURM.s(config.resolution)),
+            '-ea {}'.format(SLURM.s(config.excl_area)),
+            '-mw {}'.format(SLURM.s(config.max_workers)),
+            '-cpl {}'.format(SLURM.s(config.chunk_point_len)),
+            '-log {}'.format(SLURM.s(config.logdir)),
+            ]
 
     if config.log_level == logging.DEBUG:
-        args += '-v '
+        args.append('-v')
 
-    cmd = 'python -m reVX.wind_dirs.wind_dirs_cli {}'.format(args)
+    cmd = 'python -m reVX.wind_dirs.wind_dirs_cli {}'.format(' '.join(args))
     logger.debug('Submitting the following cli call:\n\t{}'.format(cmd))
+
     return cmd
 
 
@@ -205,19 +213,22 @@ def eagle(config):
     log_dir = config.logdir
     stdout_path = os.path.join(log_dir, 'stdout/')
 
+    slurm_manager = SLURM()
+
     logger.info('Running wind directions computation on Eagle with '
                 'node name "{}"'.format(name))
-    slurm = SLURM(cmd, alloc=config.execution_control.alloc,
-                  memory=config.execution_control.node_mem,
-                  walltime=config.execution_control.walltime,
-                  feature=config.execution_control.feature,
-                  name=name, stdout_path=stdout_path,
-                  conda_env=config.execution_control.conda_env,
-                  module=config.execution_control.module)
-    if slurm.id:
+    out = slurm_manager.sbatch(cmd,
+                               alloc=config.execution_control.alloc,
+                               memory=config.execution_control.node_mem,
+                               walltime=config.execution_control.walltime,
+                               feature=config.execution_control.feature,
+                               name=name, stdout_path=stdout_path,
+                               conda_env=config.execution_control.conda_env,
+                               module=config.execution_control.module)[0]
+    if out:
         msg = ('Kicked off prominent wind direction calculation "{}" '
                '(SLURM jobid #{}) on Eagle.'
-               .format(name, slurm.id))
+               .format(name, out))
     else:
         msg = ('Was unable to kick off prominent wind direction calculation '
                '"{}". Please see the stdout error messages'
